==> ogmsgui-0.1.0.tar.gz: ogmsgui-0.1.0/README.md <==
# OGMSGUI

![License](https://img.shields.io/badge/license-MIT-green)
A powerful GUI package for geographical modeling and simulation in Jupyter environments, integrating model invoking and AI assistance.

## 🌟 Features

- **Interactive Model Invoking**
  - Visual model selection and configuration
  - Real-time model execution and monitoring
  - Integrated file management system

- **AI-Powered Assistance**
  - AI integration for modeling guidance
  - Automatic task planning based on academic research
  - Context-aware suggestions and help

- **User-Friendly Interface**
  - Intuitive drag-and-drop interface
  - Real-time feedback and status updates

## 📦 Installation

```bash
pip install ogmsgui
```

## 🚀 Quick Start

### Basic Usage

<!-- 显示所有模型列表 -->
```python
from ogmsgui import ModelGUI

# 创建并显示GUI
gui = ModelGUI()
gui.create_gui()
```

<!-- 展示图片 -->
<!-- 展示模型界面 -->
![create gui](./assets/creategui.png)

<!-- 调用某个具体的模型 -->
```
from ogmsgui import ModelGUI

# 创建并显示GUI
gui = ModelGUI()
gui.show_model("地震群发滑坡概率评估预警模型")
```
<!-- 展示show model -->
![show model](./assets/showmodel.png)
![invoke model](./assets/invoke.gif)

### Using AI Assistant

```python
# Use the magic command for AI assistance
# 导入自定义模块
import ogmsgui

%ogmsChat 南京市光伏屋顶的碳减排潜力大概有多大
```

<!-- 展示ogmschat -->
![ogmsChat](./assets/ogmsChat.png)

```python
import ogmsgui

# Get task planning suggestions
%ogms_taskPlan 南京市光伏屋顶的碳减排潜力该怎么进行估算呢
```

<!-- taskPlan -->
![taskPlan](./assets/ogms_task.gif)


## 📄 License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.

## 🙏 Acknowledgments

- Thanks to all contributors who have helped with the development
- Special thanks to the geographical modeling community
- Built with support from [OpenGMS]

## 📬 Contact

- Author: Phileon Ma
- Email: mpllonggis@gmail.com

## 🔄 Updates

### Latest Version (0.1.0)
- Initial release with core functionality
- Basic model invoking features
- Basic AI functionality

### Roadmap
- [x] Enhanced AI capabilities

==> ogmsgui-0.1.2.tar.gz: ogmsgui-0.1.2/README.md <==
# OGMSGUI

![License](https://img.shields.io/badge/license-MIT-green)
A powerful GUI package for geographical modeling and simulation in Jupyter environments, integrating model invoking and AI assistance.

## 🌟 Features

- **Interactive Model Invoking**
  - Visual model selection and configuration
  - Real-time model execution and monitoring
  - Integrated file management system

- **AI-Powered Assistance**
  - AI integration for modeling guidance
  - Automatic task planning based on academic research
  - Context-aware suggestions and help

- **User-Friendly Interface**
  - Intuitive drag-and-drop interface
  - Real-time feedback and status updates

## 📦 Installation

```bash
pip install ogmsgui
```

## 🚀 Quick Start

### Basic Usage

<!-- 显示所有模型列表 -->
```python
from ogmsgui import ModelGUI

# 创建并显示GUI
gui = ModelGUI()
gui.create_gui()
```

<!-- 展示图片 -->
<!-- 展示模型界面 -->
![create gui](http://112.4.132.6:8083/data/725d73d1-b129-47cd-94a2-b8b5f66cbe14)

<!-- 调用某个具体的模型 -->
```
from ogmsgui import ModelGUI

# 创建并显示GUI
gui = ModelGUI()
gui.show_model("地震群发滑坡概率评估预警模型")
```
<!-- 展示show model -->
![show model](http://112.4.132.6:8083/data/33f9f3fc-fde1-4ec3-91e5-77c68db0485e)
![invoke model](http://112.4.132.6:8083/data/dc385280-f866-4c59-87f8-223d63863f62)

### Using AI Assistant

```python
# Use the magic command for AI assistance
# 导入自定义模块
import ogmsgui

%ogmsChat 南京市光伏屋顶的碳减排潜力大概有多大
```

<!-- 展示ogmschat -->
![ogmsChat](http://112.4.132.6:8083/data/856faf5e-07bc-4dbb-8853-e53284d5f97f)

```python
import ogmsgui

# Get task planning suggestions
%ogms_taskPlan 南京市光伏屋顶的碳减排潜力该怎么进行估算呢
```

<!-- taskPlan -->
![taskPlan](http://112.4.132.6:8083/data/8eedd21d-9ecf-4e53-af6d-727f3c341326)


## 📄 License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.

## 🙏 Acknowledgments

- Thanks to all contributors who have helped with the development
- Special thanks to the geographical modeling community
- Built with support from [OpenGMS]

## 📬 Contact

- Author: Phileon Ma
- Email: mpllonggis@gmail.com

## 🔄 Updates

### Latest Version (0.1.0)
- Initial release with core functionality
- Basic model invoking features
- Basic AI functionality

### Roadmap
- [x] Enhanced AI capabilities
